Middleware that adds session-based flash store that persists only to the next request in the same session.
Middleware that adds session-based flash store that persists only to the next request in the same session.
(flash-request request)Adds :flash key to request from :_flash in session.
Adds :flash key to request from :_flash in session.
(flash-response response request)If response has a :flash key, saves it in :_flash of session for next request.
If response has a :flash key, saves it in :_flash of session for next request.
(wrap-flash handler)If a :flash key is set on the response by the handler, a :flash key with the same value will be set on the next request that shares the same session. This is useful for small messages that persist across redirects.
If a :flash key is set on the response by the handler, a :flash key with the same value will be set on the next request that shares the same session. This is useful for small messages that persist across redirects.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |